/* This is part of tmview, a dvi previewer. (c) 1995 Thomas Moor         */
/*                                                                       */
/* This program may be used without any warranty. It may be modified and */
/* distributed without any restrictions.                                 */


int vffind(char*, char*, char*);
int vfdef(char*,int,long,long);
int vflookuppk(int,long);



